netapp_ontap.models.consistency_group_clone API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_clone`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupCloneSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupClone object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `guarantee: ConsistencyGroupClone1Guarantee GET POST`

    The guarantee field of the consistency_group_clone.

  `has_unsplit_flexclones: bool GET`

    Specifies if the consistency group contains any unsplit FlexClone storage units.

  `is_flexclone: bool GET`

    Specifies if this consistency group is a FlexClone of a consistency group.

  `parent_consistency_group: ConsistencyGroupClone1ParentConsistencyGroup GET POST`

    The parent_consistency_group field of the consistency_group_clone.

  `parent_snapshot: Snapshot GET POST`

    The parent_snapshot field of the consistency_group_clone.

  `parent_svm: Svm GET`

    The parent_svm field of the consistency_group_clone.

  `snaplock_type: str GET POST PATCH`

    Specifies the SnapLock type for the clone consistency group.

    Valid choices:

    - compliance
    - enterprise
    - non_snaplock
  `split_complete_percent: Size GET`

    Percentage of FlexClone blocks split from its parent consistency group.

  `split_estimate: Size GET`

    Space required to split the FlexClone consistency group.

  `split_initiated: bool GET POST PATCH`

    Splits volumes after cloning. Defaults to false during POST. Only accepts true during a PATCH.

  `storage_unit: ConsistencyGroupClone1StorageUnit GET POST PATCH`

    The storage_unit field of the consistency_group_clone.

  `unsplit_flexclones: List[str] GET`

    A list of unsplit FlexClone storage units in the consistency group.

  `volume: ConsistencyGroupClone1Volume GET POST`

    The volume field of the consistency_group_clone.